[CalendarServer-changes] [15675] CalendarServer/trunk/txdav/who/augment.py

source_changes at macosforge.org source_changes at macosforge.org
Wed Jun 15 10:31:19 PDT 2016


Revision: 15675
          http://trac.calendarserver.org//changeset/15675
Author:   sagen at apple.com
Date:     2016-06-15 10:31:19 -0700 (Wed, 15 Jun 2016)
Log Message:
-----------
Suppress error message when an augments change is not allowed to update the underlying directory service record(s)

Modified Paths:
--------------
    CalendarServer/trunk/txdav/who/augment.py

Modified: CalendarServer/trunk/txdav/who/augment.py
===================================================================
--- CalendarServer/trunk/txdav/who/augment.py	2016-06-15 05:47:42 UTC (rev 15674)
+++ CalendarServer/trunk/txdav/who/augment.py	2016-06-15 17:31:19 UTC (rev 15675)
@@ -33,7 +33,7 @@
 from twext.who.directory import DirectoryRecord
 from twext.who.directory import DirectoryService as BaseDirectoryService
 from twext.who.idirectory import (
     IDirectoryService, RecordType, FieldName as BaseFieldName
 )
 from twext.who.util import ConstantsContainer
 
@@ -334,7 +334,10 @@
 
         # Apply the base records
         if baseRecords:
-            yield self._directory.updateRecords(baseRecords, create=create)
+            try:
+                yield self._directory.updateRecords(baseRecords, create=create)
+            except NotAllowedError:
+                pass
 
 
     def _splitFields(self, record):
-------------- next part --------------
@@ -33,7 +33,7 @@
 from twext.who.directory import DirectoryService as BaseDirectoryService
 from twext.who.idirectory import (
-    IDirectoryService, RecordType, FieldName as BaseFieldName
+    IDirectoryService, RecordType, FieldName as BaseFieldName, NotAllowedError
 )
 from twext.who.util import ConstantsContainer
An HTML attachment was scrubbed...
URL: <https://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20160615/ce9e92aa/attachment.html>


More information about the calendarserver-changes mailing list